@@ -6,7 +6,7 @@ use Data::Object 'Class', 'Doodle::Library';
 
 extends 'Doodle::Grammar';
 
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 has name => (
   def => 'mysql',
@@ -320,20 +320,36 @@ Doodle Grammar For MySQL
 
   use Doodle::Grammar::Mysql;
 
-  my $self = Doodle::Grammar::Mysql->new(%args);
+  my $self = Doodle::Grammar::Mysql->new;
 
 =cut
 
 =head1 DESCRIPTION
 
-Doodle::Grammar::Mysql determines how Command classes should be interpreted to
-produce the correct DDL statements.
+This provide determines how command classes should be interpreted to produce
+the correct DDL statements for Mysql.
+
+=cut
+
+=head1 INHERITS
+
+This package inherits behaviors from:
+
+L<Doodle::Grammar>
+
+=cut
+
+=head1 LIBRARIES
+
+This package uses type constraints from:
+
+L<Doodle::Library>
 
 =cut
 
 =head1 METHODS
 
-This package implements the following methods.
+This package implements the following methods:
 
 =cut
 
@@ -345,7 +361,9 @@ Returns the SQL statement for the create column command.
 
 =over 4
 
-=item create_column example
+=item create_column example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -371,7 +389,9 @@ Returns the SQL statement for the create index command.
 
 =over 4
 
-=item create_index example
+=item create_index example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -397,7 +417,9 @@ Returns the SQL statement for the create relation command.
 
 =over 4
 
-=item create_relation example
+=item create_relation example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -424,7 +446,9 @@ Returns the SQL statement for the create schema command.
 
 =over 4
 
-=item create_schema example
+=item create_schema example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -449,7 +473,9 @@ Returns the SQL statement for the create table command.
 
 =over 4
 
-=item create_table example
+=item create_table example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -475,7 +501,9 @@ Returns the SQL statement for the delete column command.
 
 =over 4
 
-=item delete_column example
+=item delete_column example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -501,7 +529,9 @@ Returns the SQL statement for the delete index command.
 
 =over 4
 
-=item delete_index example
+=item delete_index example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -527,7 +557,9 @@ Returns the SQL statement for the delete relation command.
 
 =over 4
 
-=item delete_relation example
+=item delete_relation example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -553,7 +585,9 @@ Returns the SQL statement for the create schema command.
 
 =over 4
 
-=item delete_schema example
+=item delete_schema example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -578,7 +612,9 @@ Returns the SQL statement for the delete table command.
 
 =over 4
 
-=item delete_table example
+=item delete_table example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -604,7 +640,9 @@ Returns the SQL statement for the rename column command.
 
 =over 4
 
-=item rename_column example
+=item rename_column example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -630,7 +668,9 @@ Returns the SQL statement for the rename table command.
 
 =over 4
 
-=item rename_table example
+=item rename_table example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -656,7 +696,14 @@ Returns the type expression for a binary column.
 
 =over 4
 
-=item type_binary example
+=item type_binary example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('binary');
 
   $self->type_binary($column);
 
@@ -674,7 +721,14 @@ Returns the type expression for a boolean column.
 
 =over 4
 
-=item type_boolean example
+=item type_boolean example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('boolean');
 
   $self->type_boolean($column);
 
@@ -692,13 +746,33 @@ Returns the type expression for a char column.
 
 =over 4
 
-=item type_char example
+=item type_char example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('char');
 
   $self->type_char($column);
 
   # char(1)
 
-  $self->type_char($column, size => 10);
+=back
+
+=over 4
+
+=item type_char example #2
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('char', size => 10);
+
+  $self->type_char($column);
 
   # char(10)
 
@@ -714,7 +788,14 @@ Returns the type expression for a date column.
 
 =over 4
 
-=item type_date example
+=item type_date example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('date');
 
   $self->type_date($column);
 
@@ -732,7 +813,14 @@ Returns the type expression for a datetime column.
 
 =over 4
 
-=item type_datetime example
+=item type_datetime example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('datetime');
 
   $self->type_datetime($column);
 
@@ -750,7 +838,14 @@ Returns the type expression for a datetime_tz column.
 
 =over 4
 
-=item type_datetime_tz example
+=item type_datetime_tz example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('datetime_tz');
 
   $self->type_datetime_tz($column);
 
@@ -768,7 +863,14 @@ Returns the type expression for a decimal column.
 
 =over 4
 
-=item type_decimal example
+=item type_decimal example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('decimal');
 
   $self->type_decimal($column);
 
@@ -786,7 +888,14 @@ Returns the type expression for a double column.
 
 =over 4
 
-=item type_double example
+=item type_double example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('double');
 
   $self->type_double($column);
 
@@ -804,7 +913,14 @@ Returns the type expression for a enum column.
 
 =over 4
 
-=item type_enum example
+=item type_enum example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('enum');
 
   $self->type_enum($column);
 
@@ -822,7 +938,14 @@ Returns the type expression for a float column.
 
 =over 4
 
-=item type_float example
+=item type_float example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('float');
 
   $self->type_float($column);
 
@@ -840,7 +963,14 @@ Returns the type expression for a integer column.
 
 =over 4
 
-=item type_integer example
+=item type_integer example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('integer');
 
   $self->type_integer($column);
 
@@ -858,7 +988,14 @@ Returns the type expression for a integer_big column.
 
 =over 4
 
-=item type_integer_big example
+=item type_integer_big example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('integer_big');
 
   $self->type_integer_big($column);
 
@@ -876,7 +1013,14 @@ Returns the type expression for a integer_big_unsigned column.
 
 =over 4
 
-=item type_integer_big_unsigned example
+=item type_integer_big_unsigned example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('integer_big_unsigned');
 
   $self->type_integer_big_unsigned($column);
 
@@ -894,7 +1038,14 @@ Returns the type expression for a integer_medium column.
 
 =over 4
 
-=item type_integer_medium example
+=item type_integer_medium example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('integer_medium');
 
   $self->type_integer_medium($column);
 
@@ -912,7 +1063,14 @@ Returns the type expression for a integer_medium_unsigned column.
 
 =over 4
 
-=item type_integer_medium_unsigned example
+=item type_integer_medium_unsigned example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('integer_medium_unsigned');
 
   $self->type_integer_medium_unsigned($column);
 
@@ -930,7 +1088,14 @@ Returns the type expression for a integer_small column.
 
 =over 4
 
-=item type_integer_small example
+=item type_integer_small example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('integer_small');
 
   $self->type_integer_small($column);
 
@@ -948,7 +1113,14 @@ Returns the type expression for a integer_small_unsigned column.
 
 =over 4
 
-=item type_integer_small_unsigned example
+=item type_integer_small_unsigned example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('integer_small_unsigned');
 
   $self->type_integer_small_unsigned($column);
 
@@ -966,7 +1138,14 @@ Returns the type expression for a integer_tiny column.
 
 =over 4
 
-=item type_integer_tiny example
+=item type_integer_tiny example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('integer_tiny');
 
   $self->type_integer_tiny($column);
 
@@ -984,7 +1163,14 @@ Returns the type expression for a integer_tiny_unsigned column.
 
 =over 4
 
-=item type_integer_tiny_unsigned example
+=item type_integer_tiny_unsigned example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('integer_tiny_unsigned');
 
   $self->type_integer_tiny_unsigned($column);
 
@@ -1002,7 +1188,14 @@ Returns the type expression for a integer_unsigned column.
 
 =over 4
 
-=item type_integer_unsigned example
+=item type_integer_unsigned example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('integer_unsigned');
 
   $self->type_integer_unsigned($column);
 
@@ -1020,7 +1213,14 @@ Returns the type expression for a json column.
 
 =over 4
 
-=item type_json example
+=item type_json example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('json');
 
   $self->type_json($column);
 
@@ -1038,7 +1238,14 @@ Returns the type expression for a string column.
 
 =over 4
 
-=item type_string example
+=item type_string example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('string');
 
   $self->type_string($column);
 
@@ -1056,7 +1263,14 @@ Returns the type expression for a text column.
 
 =over 4
 
-=item type_text example
+=item type_text example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('text');
 
   $self->type_text($column);
 
@@ -1074,7 +1288,14 @@ Returns the type expression for a text_long column.
 
 =over 4
 
-=item type_text_long example
+=item type_text_long example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('text_long');
 
   $self->type_text_long($column);
 
@@ -1092,7 +1313,14 @@ Returns the type expression for a text_medium column.
 
 =over 4
 
-=item type_text_medium example
+=item type_text_medium example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('text_medium');
 
   $self->type_text_medium($column);
 
@@ -1110,7 +1338,14 @@ Returns the type expression for a time column.
 
 =over 4
 
-=item type_time example
+=item type_time example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('time');
 
   $self->type_time($column);
 
@@ -1128,7 +1363,14 @@ Returns the type expression for a time_tz column.
 
 =over 4
 
-=item type_time_tz example
+=item type_time_tz example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('time_tz');
 
   $self->type_time_tz($column);
 
@@ -1146,7 +1388,14 @@ Returns the type expression for a timestamp column.
 
 =over 4
 
-=item type_timestamp example
+=item type_timestamp example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('timestamp');
 
   $self->type_timestamp($column);
 
@@ -1158,13 +1407,20 @@ Returns the type expression for a timestamp column.
 
 =head2 type_timestamp_tz
 
-  type_timestamp_tz(Column $column) :
+  type_timestamp_tz(Column $column) : Str
 
 Returns the type expression for a timestamp_tz column.
 
 =over 4
 
-=item type_timestamp_tz example
+=item type_timestamp_tz example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('timestamp_tz');
 
   $self->type_timestamp_tz($column);
 
@@ -1182,7 +1438,14 @@ Returns the type expression for a uuid column.
 
 =over 4
 
-=item type_uuid example
+=item type_uuid example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('uuid');
 
   $self->type_uuid($column);
 
@@ -1194,13 +1457,15 @@ Returns the type expression for a uuid column.
 
 =head2 update_column
 
-  update_column(Command $command) : Command
+    update_column(Command $command) : Str
 
 Returns the SQL statement for the update column command.
 
 =over 4
 
-=item update_column example
+=item update_column example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -1212,13 +1477,13 @@ Returns the SQL statement for the update column command.
 
   $self->update_column($command);
 
-  # alter table [users] alter column [id] type integer
+  # alter table `users` alter column `id` type integer
 
   $command = $c->update(set => 'not null');
 
   $self->update_column($command);
 
-  # alter table [users] alter column [id] set not null
+  # alter table `users` alter column `id` set not null
 
 =back
 
@@ -1232,7 +1497,9 @@ Returns a wrapped SQL identifier.
 
 =over 4
 
-=item wrap example
+=item wrap example #1
+
+  # given: synopsis
 
   my $wrapped = $self->wrap('data');
 
@@ -1241,3 +1508,31 @@ Returns a wrapped SQL identifier.
 =back
 
 =cut
+
+=head1 AUTHOR
+
+Al Newkirk, C<awncorp@cpan.org>
+
+=head1 LICENSE
+
+Copyright (C) 2011-2019, Al Newkirk, et al.
+
+This is free software; you can redistribute it and/or modify it under the terms
+of the The Apache License, Version 2.0, as elucidated in the L<"license
+file"|https://github.com/iamalnewkirk/doodle/blob/master/LICENSE>.
+
+=head1 PROJECT
+
+L<Wiki|https://github.com/iamalnewkirk/doodle/wiki>
+
+L<Project|https://github.com/iamalnewkirk/doodle>
+
+L<Initiatives|https://github.com/iamalnewkirk/doodle/projects>
+
+L<Milestones|https://github.com/iamalnewkirk/doodle/milestones>
+
+L<Contributing|https://github.com/iamalnewkirk/doodle/blob/master/CONTRIBUTE.md>
+
+L<Issues|https://github.com/iamalnewkirk/doodle/issues>
+
+=cut
