@@ -4,9 +4,11 @@ use 5.014;
 
 use Data::Object 'Class', 'Doodle::Library';
 
+use Scalar::Util ();
+
 extends 'Doodle::Grammar';
 
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 has name => (
   def => 'postgres',
@@ -80,7 +82,10 @@ method type_enum(Column $col) {
   my $options = $col->data->{options};
 
   $name = $self->wrap($name);
-  $options = join ', ', map $self->wrap($_), @$options;
+
+  $options = join ', ',
+    map Scalar::Util::looks_like_number($_)
+      ? $_ : do{ s/'/\\'/g; "'$_'" }, @$options;
 
   return "varchar(225) check ($name in ($options))";
 }
@@ -325,20 +330,36 @@ Doodle Grammar For PostgreSQL
 
   use Doodle::Grammar::Postgres;
 
-  my $self = Doodle::Grammar::Postgres->new(%args);
+  my $self = Doodle::Grammar::Postgres->new;
 
 =cut
 
 =head1 DESCRIPTION
 
-Doodle::Grammar::Postgres determines how Command classes should be interpreted
-to produce the correct DDL statements.
+This provide determines how command classes should be interpreted to produce
+the correct DDL statements for Postgres.
+
+=cut
+
+=head1 INHERITS
+
+This package inherits behaviors from:
+
+L<Doodle::Grammar>
+
+=cut
+
+=head1 LIBRARIES
+
+This package uses type constraints from:
+
+L<Doodle::Library>
 
 =cut
 
 =head1 METHODS
 
-This package implements the following methods.
+This package implements the following methods:
 
 =cut
 
@@ -350,7 +371,9 @@ Returns the SQL statement for the create column command.
 
 =over 4
 
-=item create_column example
+=item create_column example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -376,7 +399,9 @@ Returns the SQL statement for the create index command.
 
 =over 4
 
-=item create_index example
+=item create_index example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -402,7 +427,9 @@ Returns the SQL statement for the create relation command.
 
 =over 4
 
-=item create_relation example
+=item create_relation example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -429,7 +456,9 @@ Returns the SQL statement for the create schema command.
 
 =over 4
 
-=item create_schema example
+=item create_schema example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -454,7 +483,9 @@ Returns the SQL statement for the create table command.
 
 =over 4
 
-=item create_table example
+=item create_table example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -480,7 +511,9 @@ Returns the SQL statement for the delete column command.
 
 =over 4
 
-=item delete_column example
+=item delete_column example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -506,7 +539,9 @@ Returns the SQL statement for the delete index command.
 
 =over 4
 
-=item delete_index example
+=item delete_index example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -532,7 +567,9 @@ Returns the SQL statement for the delete relation command.
 
 =over 4
 
-=item delete_relation example
+=item delete_relation example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -558,7 +595,9 @@ Returns the SQL statement for the create schema command.
 
 =over 4
 
-=item delete_schema example
+=item delete_schema example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -583,7 +622,9 @@ Returns the SQL statement for the delete table command.
 
 =over 4
 
-=item delete_table example
+=item delete_table example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -609,7 +650,9 @@ Returns the SQL statement for the rename column command.
 
 =over 4
 
-=item rename_column example
+=item rename_column example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -635,7 +678,9 @@ Returns the SQL statement for the rename table command.
 
 =over 4
 
-=item rename_table example
+=item rename_table example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -661,7 +706,14 @@ Returns the type expression for a binary column.
 
 =over 4
 
-=item type_binary example
+=item type_binary example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('binary');
 
   $self->type_binary($column);
 
@@ -679,7 +731,14 @@ Returns the type expression for a boolean column.
 
 =over 4
 
-=item type_boolean example
+=item type_boolean example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('boolean');
 
   $self->type_boolean($column);
 
@@ -697,13 +756,33 @@ Returns the type expression for a char column.
 
 =over 4
 
-=item type_char example
+=item type_char example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('char');
 
   $self->type_char($column);
 
   # char(1)
 
-  $self->type_char($column, size => 10);
+=back
+
+=over 4
+
+=item type_char example #2
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('char', size => 10);
+
+  $self->type_char($column);
 
   # char(10)
 
@@ -719,7 +798,14 @@ Returns the type expression for a date column.
 
 =over 4
 
-=item type_date example
+=item type_date example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('date');
 
   $self->type_date($column);
 
@@ -737,7 +823,14 @@ Returns the type expression for a datetime column.
 
 =over 4
 
-=item type_datetime example
+=item type_datetime example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('datetime');
 
   $self->type_datetime($column);
 
@@ -755,7 +848,14 @@ Returns the type expression for a datetime_tz column.
 
 =over 4
 
-=item type_datetime_tz example
+=item type_datetime_tz example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('datetime_tz');
 
   $self->type_datetime_tz($column);
 
@@ -773,7 +873,14 @@ Returns the type expression for a decimal column.
 
 =over 4
 
-=item type_decimal example
+=item type_decimal example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('decimal');
 
   $self->type_decimal($column);
 
@@ -791,7 +898,14 @@ Returns the type expression for a double column.
 
 =over 4
 
-=item type_double example
+=item type_double example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('double');
 
   $self->type_double($column);
 
@@ -809,11 +923,20 @@ Returns the type expression for a enum column.
 
 =over 4
 
-=item type_enum example
+=item type_enum example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('enum', options => [
+    1, "one", 2, '{"two": 2}', "3", "'three'"
+  ]);
 
   $self->type_enum($column);
 
-  # varchar(225) check ("data" in ())
+  # varchar(225) check ("enum" in (1, 'one', 2, '{"two": 2}', 3, '\'three\''))
 
 =back
 
@@ -827,7 +950,14 @@ Returns the type expression for a float column.
 
 =over 4
 
-=item type_float example
+=item type_float example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('float');
 
   $self->type_float($column);
 
@@ -845,7 +975,14 @@ Returns the type expression for a integer column.
 
 =over 4
 
-=item type_integer example
+=item type_integer example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('integer');
 
   $self->type_integer($column);
 
@@ -863,7 +1000,14 @@ Returns the type expression for a integer_big column.
 
 =over 4
 
-=item type_integer_big example
+=item type_integer_big example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('integer_big');
 
   $self->type_integer_big($column);
 
@@ -881,7 +1025,14 @@ Returns the type expression for a integer_big_unsigned column.
 
 =over 4
 
-=item type_integer_big_unsigned example
+=item type_integer_big_unsigned example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('integer_big_unsigned');
 
   $self->type_integer_big_unsigned($column);
 
@@ -899,7 +1050,14 @@ Returns the type expression for a integer_medium column.
 
 =over 4
 
-=item type_integer_medium example
+=item type_integer_medium example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('integer_medium');
 
   $self->type_integer_medium($column);
 
@@ -917,7 +1075,14 @@ Returns the type expression for a integer_medium_unsigned column.
 
 =over 4
 
-=item type_integer_medium_unsigned example
+=item type_integer_medium_unsigned example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('integer_medium_unsigned');
 
   $self->type_integer_medium_unsigned($column);
 
@@ -935,7 +1100,14 @@ Returns the type expression for a integer_small column.
 
 =over 4
 
-=item type_integer_small example
+=item type_integer_small example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('integer_small');
 
   $self->type_integer_small($column);
 
@@ -953,7 +1125,14 @@ Returns the type expression for a integer_small_unsigned column.
 
 =over 4
 
-=item type_integer_small_unsigned example
+=item type_integer_small_unsigned example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('integer_small_unsigned');
 
   $self->type_integer_small_unsigned($column);
 
@@ -971,7 +1150,14 @@ Returns the type expression for a integer_tiny column.
 
 =over 4
 
-=item type_integer_tiny example
+=item type_integer_tiny example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('integer_tiny');
 
   $self->type_integer_tiny($column);
 
@@ -989,7 +1175,14 @@ Returns the type expression for a integer_tiny_unsigned column.
 
 =over 4
 
-=item type_integer_tiny_unsigned example
+=item type_integer_tiny_unsigned example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('integer_tiny_unsigned');
 
   $self->type_integer_tiny_unsigned($column);
 
@@ -1007,7 +1200,14 @@ Returns the type expression for a integer_unsigned column.
 
 =over 4
 
-=item type_integer_unsigned example
+=item type_integer_unsigned example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('integer_unsigned');
 
   $self->type_integer_unsigned($column);
 
@@ -1025,7 +1225,14 @@ Returns the type expression for a json column.
 
 =over 4
 
-=item type_json example
+=item type_json example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('json');
 
   $self->type_json($column);
 
@@ -1043,7 +1250,14 @@ Returns the type expression for a string column.
 
 =over 4
 
-=item type_string example
+=item type_string example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('string');
 
   $self->type_string($column);
 
@@ -1061,7 +1275,14 @@ Returns the type expression for a text column.
 
 =over 4
 
-=item type_text example
+=item type_text example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('text');
 
   $self->type_text($column);
 
@@ -1079,7 +1300,14 @@ Returns the type expression for a text_long column.
 
 =over 4
 
-=item type_text_long example
+=item type_text_long example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('text_long');
 
   $self->type_text_long($column);
 
@@ -1097,7 +1325,14 @@ Returns the type expression for a text_medium column.
 
 =over 4
 
-=item type_text_medium example
+=item type_text_medium example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('text_medium');
 
   $self->type_text_medium($column);
 
@@ -1115,7 +1350,14 @@ Returns the type expression for a time column.
 
 =over 4
 
-=item type_time example
+=item type_time example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('time');
 
   $self->type_time($column);
 
@@ -1133,7 +1375,14 @@ Returns the type expression for a time_tz column.
 
 =over 4
 
-=item type_time_tz example
+=item type_time_tz example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('time_tz');
 
   $self->type_time_tz($column);
 
@@ -1151,7 +1400,14 @@ Returns the type expression for a timestamp column.
 
 =over 4
 
-=item type_timestamp example
+=item type_timestamp example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('timestamp');
 
   $self->type_timestamp($column);
 
@@ -1163,13 +1419,20 @@ Returns the type expression for a timestamp column.
 
 =head2 type_timestamp_tz
 
-  type_timestamp_tz(Column $column) :
+  type_timestamp_tz(Column $column) : Str
 
 Returns the type expression for a timestamp_tz column.
 
 =over 4
 
-=item type_timestamp_tz example
+=item type_timestamp_tz example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('timestamp_tz');
 
   $self->type_timestamp_tz($column);
 
@@ -1187,7 +1450,14 @@ Returns the type expression for a uuid column.
 
 =over 4
 
-=item type_uuid example
+=item type_uuid example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('uuid');
 
   $self->type_uuid($column);
 
@@ -1199,13 +1469,15 @@ Returns the type expression for a uuid column.
 
 =head2 update_column
 
-  update_column(Command $command) : Command
+  update_column(Command $command) : Str
 
 Returns the SQL statement for the update column command.
 
 =over 4
 
-=item update_column example
+=item update_column example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -1237,7 +1509,9 @@ Returns a wrapped SQL identifier.
 
 =over 4
 
-=item wrap example
+=item wrap example #1
+
+  # given: synopsis
 
   my $wrapped = $self->wrap('data');
 
@@ -1246,3 +1520,31 @@ Returns a wrapped SQL identifier.
 =back
 
 =cut
+
+=head1 AUTHOR
+
+Al Newkirk, C<awncorp@cpan.org>
+
+=head1 LICENSE
+
+Copyright (C) 2011-2019, Al Newkirk, et al.
+
+This is free software; you can redistribute it and/or modify it under the terms
+of the The Apache License, Version 2.0, as elucidated in the L<"license
+file"|https://github.com/iamalnewkirk/doodle/blob/master/LICENSE>.
+
+=head1 PROJECT
+
+L<Wiki|https://github.com/iamalnewkirk/doodle/wiki>
+
+L<Project|https://github.com/iamalnewkirk/doodle>
+
+L<Initiatives|https://github.com/iamalnewkirk/doodle/projects>
+
+L<Milestones|https://github.com/iamalnewkirk/doodle/milestones>
+
+L<Contributing|https://github.com/iamalnewkirk/doodle/blob/master/CONTRIBUTE.md>
+
+L<Issues|https://github.com/iamalnewkirk/doodle/issues>
+
+=cut
