@@ -6,7 +6,7 @@ use Data::Object 'Class', 'Doodle::Library';
 
 extends 'Doodle::Grammar';
 
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 has name => (
   def => 'sqlite',
@@ -282,20 +282,36 @@ Doodle Grammar For SQLite
 
   use Doodle::Grammar::Sqlite;
 
-  my $self = Doodle::Grammar::Sqlite->new(%args);
+  my $self = Doodle::Grammar::Sqlite->new;
 
 =cut
 
 =head1 DESCRIPTION
 
-Doodle::Grammar::Sqlite determines how Command classes should be interpreted to
-produce the correct DDL statements.
+This provide determines how command classes should be interpreted to produce
+the correct DDL statements for Sqlite.
+
+=cut
+
+=head1 INHERITS
+
+This package inherits behaviors from:
+
+L<Doodle::Grammar>
+
+=cut
+
+=head1 LIBRARIES
+
+This package uses type constraints from:
+
+L<Doodle::Library>
 
 =cut
 
 =head1 METHODS
 
-This package implements the following methods.
+This package implements the following methods:
 
 =cut
 
@@ -307,7 +323,9 @@ Returns the SQL statement for the create column command.
 
 =over 4
 
-=item create_column example
+=item create_column example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -333,7 +351,9 @@ Returns the SQL statement for the create index command.
 
 =over 4
 
-=item create_index example
+=item create_index example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -359,7 +379,9 @@ Returns the SQL statement for the create table command.
 
 =over 4
 
-=item create_table example
+=item create_table example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -385,7 +407,9 @@ Returns the SQL statement for the delete column command.
 
 =over 4
 
-=item delete_column example
+=item delete_column example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -411,7 +435,9 @@ Returns the SQL statement for the delete index command.
 
 =over 4
 
-=item delete_index example
+=item delete_index example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -437,7 +463,9 @@ Returns the SQL statement for the delete table command.
 
 =over 4
 
-=item delete_table example
+=item delete_table example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -463,7 +491,9 @@ Returns the SQL statement for the rename table command.
 
 =over 4
 
-=item rename_table example
+=item rename_table example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -489,7 +519,14 @@ Returns the type expression for a binary column.
 
 =over 4
 
-=item type_binary example
+=item type_binary example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('binary');
 
   $self->type_binary($column);
 
@@ -507,7 +544,14 @@ Returns the type expression for a boolean column.
 
 =over 4
 
-=item type_boolean example
+=item type_boolean example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('boolean');
 
   $self->type_boolean($column);
 
@@ -525,7 +569,14 @@ Returns the type expression for a char column.
 
 =over 4
 
-=item type_char example
+=item type_char example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('char');
 
   $self->type_char($column);
 
@@ -543,7 +594,14 @@ Returns the type expression for a date column.
 
 =over 4
 
-=item type_date example
+=item type_date example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('date');
 
   $self->type_date($column);
 
@@ -561,7 +619,14 @@ Returns the type expression for a datetime column.
 
 =over 4
 
-=item type_datetime example
+=item type_datetime example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('datetime');
 
   $self->type_datetime($column);
 
@@ -579,7 +644,14 @@ Returns the type expression for a datetime_tz column.
 
 =over 4
 
-=item type_datetime_tz example
+=item type_datetime_tz example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('datetime_tz');
 
   $self->type_datetime_tz($column);
 
@@ -597,7 +669,14 @@ Returns the type expression for a decimal column.
 
 =over 4
 
-=item type_decimal example
+=item type_decimal example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('decimal');
 
   $self->type_decimal($column);
 
@@ -615,7 +694,14 @@ Returns the type expression for a double column.
 
 =over 4
 
-=item type_double example
+=item type_double example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('double');
 
   $self->type_double($column);
 
@@ -633,7 +719,14 @@ Returns the type expression for a enum column.
 
 =over 4
 
-=item type_enum example
+=item type_enum example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('enum');
 
   $self->type_enum($column);
 
@@ -651,7 +744,14 @@ Returns the type expression for a float column.
 
 =over 4
 
-=item type_float example
+=item type_float example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('float');
 
   $self->type_float($column);
 
@@ -669,7 +769,14 @@ Returns the type expression for a integer column.
 
 =over 4
 
-=item type_integer example
+=item type_integer example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('integer');
 
   $self->type_integer($column);
 
@@ -687,7 +794,14 @@ Returns the type expression for a integer_big column.
 
 =over 4
 
-=item type_integer_big example
+=item type_integer_big example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('integer_big');
 
   $self->type_integer_big($column);
 
@@ -705,7 +819,14 @@ Returns the type expression for a integer_big_unsigned column.
 
 =over 4
 
-=item type_integer_big_unsigned example
+=item type_integer_big_unsigned example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('integer_big_unsigned');
 
   $self->type_integer_big_unsigned($column);
 
@@ -723,7 +844,14 @@ Returns the type expression for a integer_medium column.
 
 =over 4
 
-=item type_integer_medium example
+=item type_integer_medium example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('integer_medium');
 
   $self->type_integer_medium($column);
 
@@ -741,7 +869,14 @@ Returns the type expression for a integer_medium_unsigned column.
 
 =over 4
 
-=item type_integer_medium_unsigned example
+=item type_integer_medium_unsigned example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('integer_medium_unsigned');
 
   $self->type_integer_medium_unsigned($column);
 
@@ -759,7 +894,14 @@ Returns the type expression for a integer_small column.
 
 =over 4
 
-=item type_integer_small example
+=item type_integer_small example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('integer_small');
 
   $self->type_integer_small($column);
 
@@ -777,7 +919,14 @@ Returns the type expression for a integer_small_unsigned column.
 
 =over 4
 
-=item type_integer_small_unsigned example
+=item type_integer_small_unsigned example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('integer_small_unsigned');
 
   $self->type_integer_small_unsigned($column);
 
@@ -795,7 +944,14 @@ Returns the type expression for a integer_tiny column.
 
 =over 4
 
-=item type_integer_tiny example
+=item type_integer_tiny example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('integer_tiny');
 
   $self->type_integer_tiny($column);
 
@@ -813,7 +969,14 @@ Returns the type expression for a integer_tiny_unsigned column.
 
 =over 4
 
-=item type_integer_tiny_unsigned example
+=item type_integer_tiny_unsigned example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('integer_tiny_unsigned');
 
   $self->type_integer_tiny_unsigned($column);
 
@@ -831,7 +994,14 @@ Returns the type expression for a integer_unsigned column.
 
 =over 4
 
-=item type_integer_unsigned example
+=item type_integer_unsigned example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('integer_unsigned');
 
   $self->type_integer_unsigned($column);
 
@@ -849,7 +1019,14 @@ Returns the type expression for a json column.
 
 =over 4
 
-=item type_json example
+=item type_json example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('json');
 
   $self->type_json($column);
 
@@ -867,7 +1044,14 @@ Returns the type expression for a string column.
 
 =over 4
 
-=item type_string example
+=item type_string example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('string');
 
   $self->type_string($column);
 
@@ -885,7 +1069,14 @@ Returns the type expression for a text column.
 
 =over 4
 
-=item type_text example
+=item type_text example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('text');
 
   $self->type_text($column);
 
@@ -903,7 +1094,14 @@ Returns the type expression for a text_long column.
 
 =over 4
 
-=item type_text_long example
+=item type_text_long example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('text_long');
 
   $self->type_text_long($column);
 
@@ -921,7 +1119,14 @@ Returns the type expression for a text_medium column.
 
 =over 4
 
-=item type_text_medium example
+=item type_text_medium example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('text_medium');
 
   $self->type_text_medium($column);
 
@@ -939,7 +1144,14 @@ Returns the type expression for a time column.
 
 =over 4
 
-=item type_time example
+=item type_time example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('time');
 
   $self->type_time($column);
 
@@ -957,7 +1169,14 @@ Returns the type expression for a time_tz column.
 
 =over 4
 
-=item type_time_tz example
+=item type_time_tz example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('time_tz');
 
   $self->type_time_tz($column);
 
@@ -975,7 +1194,14 @@ Returns the type expression for a timestamp column.
 
 =over 4
 
-=item type_timestamp example
+=item type_timestamp example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('timestamp');
 
   $self->type_timestamp($column);
 
@@ -993,7 +1219,14 @@ Returns the type expression for a timestamp_tz column.
 
 =over 4
 
-=item type_timestamp_tz example
+=item type_timestamp_tz example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('timestamp_tz');
 
   $self->type_timestamp_tz($column);
 
@@ -1011,7 +1244,14 @@ Returns the type expression for a uuid column.
 
 =over 4
 
-=item type_uuid example
+=item type_uuid example #1
+
+  # given: synopsis
+
+  use Doodle;
+
+  my $ddl = Doodle->new;
+  my $column = $ddl->table('users')->column('uuid');
 
   $self->type_uuid($column);
 
@@ -1023,13 +1263,15 @@ Returns the type expression for a uuid column.
 
 =head2 update_column
 
-  update_column(Command $command) : Command
+  update_column(Command $command) : Str
 
 Returns the SQL statement for the update column command.
 
 =over 4
 
-=item update_column example
+=item update_column example #1
+
+  # given: synopsis
 
   use Doodle;
 
@@ -1061,7 +1303,9 @@ Returns a wrapped SQL identifier.
 
 =over 4
 
-=item wrap example
+=item wrap example #1
+
+  # given: synopsis
 
   my $wrapped = $self->wrap('data');
 
@@ -1070,3 +1314,31 @@ Returns a wrapped SQL identifier.
 =back
 
 =cut
+
+=head1 AUTHOR
+
+Al Newkirk, C<awncorp@cpan.org>
+
+=head1 LICENSE
+
+Copyright (C) 2011-2019, Al Newkirk, et al.
+
+This is free software; you can redistribute it and/or modify it under the terms
+of the The Apache License, Version 2.0, as elucidated in the L<"license
+file"|https://github.com/iamalnewkirk/doodle/blob/master/LICENSE>.
+
+=head1 PROJECT
+
+L<Wiki|https://github.com/iamalnewkirk/doodle/wiki>
+
+L<Project|https://github.com/iamalnewkirk/doodle>
+
+L<Initiatives|https://github.com/iamalnewkirk/doodle/projects>
+
+L<Milestones|https://github.com/iamalnewkirk/doodle/milestones>
+
+L<Contributing|https://github.com/iamalnewkirk/doodle/blob/master/CONTRIBUTE.md>
+
+L<Issues|https://github.com/iamalnewkirk/doodle/issues>
+
+=cut
